﻿using SciChart.Charting.Model.DataSeries;
using SciChart.Charting.Visuals.Annotations;
using SciChart.Charting.Visuals.PointMarkers;
using SciChart.Charting.Visuals.RenderableSeries;
using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Media;
using System.Windows.Media.Imaging;

namespace SciChartMitigation
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void chartLoaded(object sender, RoutedEventArgs e)
        {
            var xValues = new List<double> { 3.5, 4.1, 6.1, 8.9 };
            var yValues = new List<double> { 8.1, 2.5, 3.7, 5.5 };

            var dataSeries = new XyDataSeries<double, double>();
            dataSeries.Append(xValues, yValues);
            dataSeries.SeriesName = "Some Series";

            var renderableSeries = new XyScatterRenderableSeries
            {
                DataSeries = dataSeries,
                PointMarker = new EllipsePointMarker
                {
                    Height = 10,
                    Width = 10,
                    Stroke = Colors.White,
                    Fill = Colors.Red
                }
            };

            scatterPlot.RenderableSeries.Add(renderableSeries);
        }

        private void scatterPlot_MouseRightButtonUp(object sender, System.Windows.Input.MouseButtonEventArgs e)
        {
            var hitTestPoint = e.GetPosition(scatterPlot.GridLinesPanel as UIElement);

            foreach (var renderableSeries in scatterPlot.RenderableSeries)
            {
                var hitTestInfo = renderableSeries.HitTest(hitTestPoint, true);

                var xValue = hitTestInfo.XValue;
                var yValue = hitTestInfo.YValue;
                var dataSeriesName = hitTestInfo.DataSeriesName;

                if (hitTestInfo.IsHit)
                {
                    var annotation = new MyCustomAnnotation
                    {
                        HorizontalAnchorPoint = HorizontalAnchorPoint.Right,
                        VerticalAnchorPoint = VerticalAnchorPoint.Bottom,
                        IsEditable = true,
                        X1 = xValue,
                        Y1 = yValue
                    };

                    annotation.AnnotationText.Text = dataSeriesName;
                    annotation.AnnotationText.Foreground = new SolidColorBrush(renderableSeries.Stroke);

                    const string image = "/image/smileyFace.png";

                    var bitmapImageSource = new BitmapImage();
                    bitmapImageSource.BeginInit();
                    bitmapImageSource.UriSource = new Uri(image, UriKind.Relative);
                    bitmapImageSource.EndInit();

                    annotation.AnnotationImage.Visibility = Visibility.Visible;
                    annotation.AnnotationImage.Stretch = Stretch.Uniform;

                    annotation.annotationImage.Source = bitmapImageSource;

                    scatterPlot.Annotations.Add(annotation);
                }

            }
        }

        private void clearAnnotations(object sender, RoutedEventArgs e)
        {
            scatterPlot.Annotations.Clear();
        }

        private void removeImage(object sender, RoutedEventArgs e)
        {
            foreach (var annotationRaw in scatterPlot.Annotations)
            {
                var annotation = annotationRaw as MyCustomAnnotation;

                var xLocation = annotation.X1;
                var yLocation = annotation.Y1;

                annotation.AnnotationImage.Source = null;
                annotation.AnnotationImage.Visibility = Visibility.Collapsed;

                annotation.X1 = xLocation;
                annotation.Y1 = yLocation;
            }
        }
    }
}
